==> cloud9-1.0.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/services/cloud9/CfnEnvironmentEC2Props.java <==
package software.amazon.awscdk.services.cloud9;

/**
 * Properties for defining a `AWS::Cloud9::EnvironmentEC2`.
 * 
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cloud9-environmentec2.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.14.0 (build a586a1a)", date = "2019-07-11T14:04:44.509Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnEnvironmentEC2Props extends software.amazon.jsii.JsiiSerializable {
    /**
     * `AWS::Cloud9::EnvironmentEC2.InstanceType`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cloud9-environmentec2.html#cfn-cloud9-environmentec2-instancetype
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    java.lang.String getInstanceType();
    /**
     * `AWS::Cloud9::EnvironmentEC2.AutomaticStopTimeMinutes`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cloud9-environmentec2.html#cfn-cloud9-environmentec2-automaticstoptimeminutes
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    java.lang.Number getAutomaticStopTimeMinutes();
    /**
     * `AWS::Cloud9::EnvironmentEC2.Description`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cloud9-environmentec2.html#cfn-cloud9-environmentec2-description
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    java.lang.String getDescription();
    /**
     * `AWS::Cloud9::EnvironmentEC2.Name`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cloud9-environmentec2.html#cfn-cloud9-environmentec2-name
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    java.lang.String getName();
    /**
     * `AWS::Cloud9::EnvironmentEC2.OwnerArn`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cloud9-environmentec2.html#cfn-cloud9-environmentec2-ownerarn
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    java.lang.String getOwnerArn();
    /**
     * `AWS::Cloud9::EnvironmentEC2.Repositories`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cloud9-environmentec2.html#cfn-cloud9-environmentec2-repositories
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    java.lang.Object getRepositories();
    /**
     * `AWS::Cloud9::EnvironmentEC2.SubnetId`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cloud9-environmentec2.html#cfn-cloud9-environmentec2-subnetid
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    java.lang.String getSubnetId();

    /**
     * @return a {@link Builder} of {@link CfnEnvironmentEC2Props}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }

    /**
     * A builder for {@link CfnEnvironmentEC2Props}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    final class Builder {
        private java.lang.String _instanceType;
        @javax.annotation.Nullable
        private java.lang.Number _automaticStopTimeMinutes;
        @javax.annotation.Nullable
        private java.lang.String _description;
        @javax.annotation.Nullable
        private java.lang.String _name;
        @javax.annotation.Nullable
        private java.lang.String _ownerArn;
        @javax.annotation.Nullable
        private java.lang.Object _repositories;
        @javax.annotation.Nullable
        private java.lang.String _subnetId;

        /**
         * Sets the value of InstanceType
         * @param value `AWS::Cloud9::EnvironmentEC2.InstanceType`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder withInstanceType(final java.lang.String value) {
            this._instanceType = java.util.Objects.requireNonNull(value, "instanceType is required");
            return this;
        }
        /**
         * Sets the value of AutomaticStopTimeMinutes
         * @param value `AWS::Cloud9::EnvironmentEC2.AutomaticStopTimeMinutes`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder withAutomaticStopTimeMinutes(@javax.annotation.Nullable final java.lang.Number value) {
            this._automaticStopTimeMinutes = value;
            return this;
        }
        /**
         * Sets the value of Description
         * @param value `AWS::Cloud9::EnvironmentEC2.Description`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder withDescription(@javax.annotation.Nullable final java.lang.String value) {
            this._description = value;
            return this;
        }
        /**
         * Sets the value of Name
         * @param value `AWS::Cloud9::EnvironmentEC2.Name`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder withName(@javax.annotation.Nullable final java.lang.String value) {
            this._name = value;
            return this;
        }
        /**
         * Sets the value of OwnerArn
         * @param value `AWS::Cloud9::EnvironmentEC2.OwnerArn`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder withOwnerArn(@javax.annotation.Nullable final java.lang.String value) {
            this._ownerArn = value;
            return this;
        }
        /**
         * Sets the value of Repositories
         * @param value `AWS::Cloud9::EnvironmentEC2.Repositories`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder withRepositories(@javax.annotation.Nullable final software.amazon.awscdk.core.IResolvable value) {
            this._repositories = value;
            return this;
        }
        /**
         * Sets the value of Repositories
         * @param value `AWS::Cloud9::EnvironmentEC2.Repositories`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder withRepositories(@javax.annotation.Nullable final java.util.List<java.lang.Object> value) {
            this._repositories = value;
            return this;
        }
        /**
         * Sets the value of SubnetId
         * @param value `AWS::Cloud9::EnvironmentEC2.SubnetId`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder withSubnetId(@javax.annotation.Nullable final java.lang.String value) {
            this._subnetId = value;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnEnvironmentEC2Props}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public CfnEnvironmentEC2Props build() {
            return new CfnEnvironmentEC2Props() {
                private final java.lang.String $instanceType = java.util.Objects.requireNonNull(_instanceType, "instanceType is required");
                @javax.annotation.Nullable
                private final java.lang.Number $automaticStopTimeMinutes = _automaticStopTimeMinutes;
                @javax.annotation.Nullable
                private final java.lang.String $description = _description;
                @javax.annotation.Nullable
                private final java.lang.String $name = _name;
                @javax.annotation.Nullable
                private final java.lang.String $ownerArn = _ownerArn;
                @javax.annotation.Nullable
                private final java.lang.Object $repositories = _repositories;
                @javax.annotation.Nullable
                private final java.lang.String $subnetId = _subnetId;

                @Override
                public java.lang.String getInstanceType() {
                    return this.$instanceType;
                }

                @Override
                public java.lang.Number getAutomaticStopTimeMinutes() {
                    return this.$automaticStopTimeMinutes;
                }

                @Override
                public java.lang.String getDescription() {
                    return this.$description;
                }

                @Override
                public java.lang.String getName() {
                    return this.$name;
                }

                @Override
                public java.lang.String getOwnerArn() {
                    return this.$ownerArn;
                }

                @Override
                public java.lang.Object getRepositories() {
                    return this.$repositories;
                }

                @Override
                public java.lang.String getSubnetId() {
                    return this.$subnetId;
                }

                public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
                    com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
                    com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
                    obj.set("instanceType", om.valueToTree(this.getInstanceType()));
                    if (this.getAutomaticStopTimeMinutes() != null) {
                        obj.set("automaticStopTimeMinutes", om.valueToTree(this.getAutomaticStopTimeMinutes()));
                    }
                    if (this.getDescription() != null) {
                        obj.set("description", om.valueToTree(this.getDescription()));
                    }
                    if (this.getName() != null) {
                        obj.set("name", om.valueToTree(this.getName()));
                    }
                    if (this.getOwnerArn() != null) {
                        obj.set("ownerArn", om.valueToTree(this.getOwnerArn()));
                    }
                    if (this.getRepositories() != null) {
                        obj.set("repositories", om.valueToTree(this.getRepositories()));
                    }
                    if (this.getSubnetId() != null) {
                        obj.set("subnetId", om.valueToTree(this.getSubnetId()));
                    }
                    return obj;
                }

            };
        }
    }

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.cloud9.CfnEnvironmentEC2Props {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
            super(mode);
        }

        /**
         * `AWS::Cloud9::EnvironmentEC2.InstanceType`.
         * 
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cloud9-environmentec2.html#cfn-cloud9-environmentec2-instancetype
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public java.lang.String getInstanceType() {
            return this.jsiiGet("instanceType", java.lang.String.class);
        }

        /**
         * `AWS::Cloud9::EnvironmentEC2.AutomaticStopTimeMinutes`.
         * 
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cloud9-environmentec2.html#cfn-cloud9-environmentec2-automaticstoptimeminutes
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @javax.annotation.Nullable
        public java.lang.Number getAutomaticStopTimeMinutes() {
            return this.jsiiGet("automaticStopTimeMinutes", java.lang.Number.class);
        }

        /**
         * `AWS::Cloud9::EnvironmentEC2.Description`.
         * 
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cloud9-environmentec2.html#cfn-cloud9-environmentec2-description
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @javax.annotation.Nullable
        public java.lang.String getDescription() {
            return this.jsiiGet("description", java.lang.String.class);
        }

        /**
         * `AWS::Cloud9::EnvironmentEC2.Name`.
         * 
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cloud9-environmentec2.html#cfn-cloud9-environmentec2-name
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @javax.annotation.Nullable
        public java.lang.String getName() {
            return this.jsiiGet("name", java.lang.String.class);
        }

        /**
         * `AWS::Cloud9::EnvironmentEC2.OwnerArn`.
         * 
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cloud9-environmentec2.html#cfn-cloud9-environmentec2-ownerarn
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @javax.annotation.Nullable
        public java.lang.String getOwnerArn() {
            return this.jsiiGet("ownerArn", java.lang.String.class);
        }

        /**
         * `AWS::Cloud9::EnvironmentEC2.Repositories`.
         * 
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cloud9-environmentec2.html#cfn-cloud9-environmentec2-repositories
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @javax.annotation.Nullable
        public java.lang.Object getRepositories() {
            return this.jsiiGet("repositories", java.lang.Object.class);
        }

        /**
         * `AWS::Cloud9::EnvironmentEC2.SubnetId`.
         * 
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cloud9-environmentec2.html#cfn-cloud9-environmentec2-subnetid
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @javax.annotation.Nullable
        public java.lang.String getSubnetId() {
            return this.jsiiGet("subnetId", java.lang.String.class);
        }
    }
}

==> cloud9-1.1.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/services/cloud9/CfnEnvironmentEC2Props.java <==
package software.amazon.awscdk.services.cloud9;

/**
 * Properties for defining a `AWS::Cloud9::EnvironmentEC2`.
 * 
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cloud9-environmentec2.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.14.2 (build e881f16)", date = "2019-07-19T18:58:07.565Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
public interface CfnEnvironmentEC2Props extends software.amazon.jsii.JsiiSerializable {
    /**
     * `AWS::Cloud9::EnvironmentEC2.InstanceType`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cloud9-environmentec2.html#cfn-cloud9-environmentec2-instancetype
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.String getInstanceType();
    /**
     * `AWS::Cloud9::EnvironmentEC2.AutomaticStopTimeMinutes`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cloud9-environmentec2.html#cfn-cloud9-environmentec2-automaticstoptimeminutes
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.Number getAutomaticStopTimeMinutes();
    /**
     * `AWS::Cloud9::EnvironmentEC2.Description`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cloud9-environmentec2.html#cfn-cloud9-environmentec2-description
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.String getDescription();
    /**
     * `AWS::Cloud9::EnvironmentEC2.Name`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cloud9-environmentec2.html#cfn-cloud9-environmentec2-name
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.String getName();
    /**
     * `AWS::Cloud9::EnvironmentEC2.OwnerArn`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cloud9-environmentec2.html#cfn-cloud9-environmentec2-ownerarn
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.String getOwnerArn();
    /**
     * `AWS::Cloud9::EnvironmentEC2.Repositories`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cloud9-environmentec2.html#cfn-cloud9-environmentec2-repositories
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.Object getRepositories();
    /**
     * `AWS::Cloud9::EnvironmentEC2.SubnetId`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cloud9-environmentec2.html#cfn-cloud9-environmentec2-subnetid
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.String getSubnetId();

    /**
     * @return a {@link Builder} of {@link CfnEnvironmentEC2Props}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    static Builder builder() {
        return new Builder();
    }

    /**
     * A builder for {@link CfnEnvironmentEC2Props}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    final class Builder {
        private java.lang.String _instanceType;
        @javax.annotation.Nullable
        private java.lang.Number _automaticStopTimeMinutes;
        @javax.annotation.Nullable
        private java.lang.String _description;
        @javax.annotation.Nullable
        private java.lang.String _name;
        @javax.annotation.Nullable
        private java.lang.String _ownerArn;
        @javax.annotation.Nullable
        private java.lang.Object _repositories;
        @javax.annotation.Nullable
        private java.lang.String _subnetId;

        /**
         * Sets the value of InstanceType
         * @param value `AWS::Cloud9::EnvironmentEC2.InstanceType`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder withInstanceType(final java.lang.String value) {
            this._instanceType = java.util.Objects.requireNonNull(value, "instanceType is required");
            return this;
        }
        /**
         * Sets the value of AutomaticStopTimeMinutes
         * @param value `AWS::Cloud9::EnvironmentEC2.AutomaticStopTimeMinutes`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder withAutomaticStopTimeMinutes(@javax.annotation.Nullable final java.lang.Number value) {
            this._automaticStopTimeMinutes = value;
            return this;
        }
        /**
         * Sets the value of Description
         * @param value `AWS::Cloud9::EnvironmentEC2.Description`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder withDescription(@javax.annotation.Nullable final java.lang.String value) {
            this._description = value;
            return this;
        }
        /**
         * Sets the value of Name
         * @param value `AWS::Cloud9::EnvironmentEC2.Name`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder withName(@javax.annotation.Nullable final java.lang.String value) {
            this._name = value;
            return this;
        }
        /**
         * Sets the value of OwnerArn
         * @param value `AWS::Cloud9::EnvironmentEC2.OwnerArn`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder withOwnerArn(@javax.annotation.Nullable final java.lang.String value) {
            this._ownerArn = value;
            return this;
        }
        /**
         * Sets the value of Repositories
         * @param value `AWS::Cloud9::EnvironmentEC2.Repositories`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder withRepositories(@javax.annotation.Nullable final software.amazon.awscdk.core.IResolvable value) {
            this._repositories = value;
            return this;
        }
        /**
         * Sets the value of Repositories
         * @param value `AWS::Cloud9::EnvironmentEC2.Repositories`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder withRepositories(@javax.annotation.Nullable final java.util.List<java.lang.Object> value) {
            this._repositories = value;
            return this;
        }
        /**
         * Sets the value of SubnetId
         * @param value `AWS::Cloud9::EnvironmentEC2.SubnetId`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder withSubnetId(@javax.annotation.Nullable final java.lang.String value) {
            this._subnetId = value;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnEnvironmentEC2Props}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public CfnEnvironmentEC2Props build() {
            return new CfnEnvironmentEC2Props() {
                private final java.lang.String $instanceType = java.util.Objects.requireNonNull(_instanceType, "instanceType is required");
                @javax.annotation.Nullable
                private final java.lang.Number $automaticStopTimeMinutes = _automaticStopTimeMinutes;
                @javax.annotation.Nullable
                private final java.lang.String $description = _description;
                @javax.annotation.Nullable
                private final java.lang.String $name = _name;
                @javax.annotation.Nullable
                private final java.lang.String $ownerArn = _ownerArn;
                @javax.annotation.Nullable
                private final java.lang.Object $repositories = _repositories;
                @javax.annotation.Nullable
                private final java.lang.String $subnetId = _subnetId;

                @Override
                public java.lang.String getInstanceType() {
                    return this.$instanceType;
                }

                @Override
                public java.lang.Number getAutomaticStopTimeMinutes() {
                    return this.$automaticStopTimeMinutes;
                }

                @Override
                public java.lang.String getDescription() {
                    return this.$description;
                }

                @Override
                public java.lang.String getName() {
                    return this.$name;
                }

                @Override
                public java.lang.String getOwnerArn() {
                    return this.$ownerArn;
                }

                @Override
                public java.lang.Object getRepositories() {
                    return this.$repositories;
                }

                @Override
                public java.lang.String getSubnetId() {
                    return this.$subnetId;
                }

                public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
                    com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
                    com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
                    obj.set("instanceType", om.valueToTree(this.getInstanceType()));
                    if (this.getAutomaticStopTimeMinutes() != null) {
                        obj.set("automaticStopTimeMinutes", om.valueToTree(this.getAutomaticStopTimeMinutes()));
                    }
                    if (this.getDescription() != null) {
                        obj.set("description", om.valueToTree(this.getDescription()));
                    }
                    if (this.getName() != null) {
                        obj.set("name", om.valueToTree(this.getName()));
                    }
                    if (this.getOwnerArn() != null) {
                        obj.set("ownerArn", om.valueToTree(this.getOwnerArn()));
                    }
                    if (this.getRepositories() != null) {
                        obj.set("repositories", om.valueToTree(this.getRepositories()));
                    }
                    if (this.getSubnetId() != null) {
                        obj.set("subnetId", om.valueToTree(this.getSubnetId()));
                    }
                    return obj;
                }

            };
        }
    }

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.cloud9.CfnEnvironmentEC2Props {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
            super(mode);
        }

        /**
         * `AWS::Cloud9::EnvironmentEC2.InstanceType`.
         * 
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cloud9-environmentec2.html#cfn-cloud9-environmentec2-instancetype
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public java.lang.String getInstanceType() {
            return this.jsiiGet("instanceType", java.lang.String.class);
        }

        /**
         * `AWS::Cloud9::EnvironmentEC2.AutomaticStopTimeMinutes`.
         * 
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cloud9-environmentec2.html#cfn-cloud9-environmentec2-automaticstoptimeminutes
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        @javax.annotation.Nullable
        public java.lang.Number getAutomaticStopTimeMinutes() {
            return this.jsiiGet("automaticStopTimeMinutes", java.lang.Number.class);
        }

        /**
         * `AWS::Cloud9::EnvironmentEC2.Description`.
         * 
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cloud9-environmentec2.html#cfn-cloud9-environmentec2-description
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        @javax.annotation.Nullable
        public java.lang.String getDescription() {
            return this.jsiiGet("description", java.lang.String.class);
        }

        /**
         * `AWS::Cloud9::EnvironmentEC2.Name`.
         * 
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cloud9-environmentec2.html#cfn-cloud9-environmentec2-name
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        @javax.annotation.Nullable
        public java.lang.String getName() {
            return this.jsiiGet("name", java.lang.String.class);
        }

        /**
         * `AWS::Cloud9::EnvironmentEC2.OwnerArn`.
         * 
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cloud9-environmentec2.html#cfn-cloud9-environmentec2-ownerarn
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        @javax.annotation.Nullable
        public java.lang.String getOwnerArn() {
            return this.jsiiGet("ownerArn", java.lang.String.class);
        }

        /**
         * `AWS::Cloud9::EnvironmentEC2.Repositories`.
         * 
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cloud9-environmentec2.html#cfn-cloud9-environmentec2-repositories
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        @javax.annotation.Nullable
        public java.lang.Object getRepositories() {
            return this.jsiiGet("repositories", java.lang.Object.class);
        }

        /**
         * `AWS::Cloud9::EnvironmentEC2.SubnetId`.
         * 
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cloud9-environmentec2.html#cfn-cloud9-environmentec2-subnetid
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        @javax.annotation.Nullable
        public java.lang.String getSubnetId() {
            return this.jsiiGet("subnetId", java.lang.String.class);
        }
    }
}
